@@ -50,10 +50,13 @@ module.exports = function(hg, done) {
 					prop[1] = 'publicationyear';
 				}
 				res[prop[1]] = prop[2].replace(/<.*?>/g, '');
-				if (prop[1] == 'publicationyear') {
-					res.date = (new Date(res.publicationyear)).toUTCString();
-				}
 			});
+			if (res.publicationyear) {
+				res.date = (new Date(res.publicationyear)).toUTCString();
+			}
+			if (res.degreeawarded) {
+				res.type += ' - ' + res.degreeawarded;
+			}
 		}
 		res.body = hg.cleanupBody(res.body);
 		res.title = hg.stripslashes(res.title);
