@@ -22,7 +22,7 @@ module.exports = function(hg) {
 			}
 		}
 		if (item.domain == 'groups') {
-			if (item.discoverability === 1 && !args.groupMap[item.id]) {
+			if (item.discoverability == 1 && !args.groupMap[item.id]) {
 				return false;
 			}
 		}
@@ -114,7 +114,7 @@ module.exports = function(hg) {
 		return str.replace(new RegExp('[.\\\\+*?\\[\\^\\]$(){}=!<>|:\\/-]', 'g'), '\\$&');
 	};
 
-	var stopWordRe = new RegExp('([-\s]+|' + hg.getStopWords().map(reQuote).join('|') + ')*', 'gi');
+	var stopWordRe = new RegExp('(-|\\s+|' + hg.getStopWords().map(reQuote).join('|') + ')*');
 
 	var baseWeight = {
 		'titleWord': 1,
@@ -271,15 +271,15 @@ module.exports = function(hg) {
 		return new RegExp('(' + terms.map(function(term) {
 			return reQuote(term.string.split(/[-\s]+/).filter(function(word) {
 				return !hg.isStopWord(word);
-			}).join(' ')).replace(/\s+/g, stopWordRe); 
+			}).join(' ')).replace(/\s+/g, stopWordRe.toString().replace(/\//g, ''));
 		})
-		.filter(function(t) { 
-			return !hg.isStopWord(t); 
-		}) 
-		.join('|') 
+		.filter(function(t) {
+			return !hg.isStopWord(t);
+		})
+		.join('|')
 		+ ')', 'gi');
 	};
-	
+
 	var excerpt = function(t, termRe, isChild) {
 		var ctx = {
 			'before': 150,
@@ -436,11 +436,11 @@ module.exports = function(hg) {
 		});
 
 		if (terms && terms.negative.length) {
-			var re = getTermRe(terms.negative); 
+			var re = getTermRe(terms.negative);
 			validators.push(function(item) { return !re.test(item.title) && !re.test(item.body); });
 		}
 		if (terms && terms.mandatory.length) {
-			var re = getTermRe(terms.mandatory); 
+			var re = getTermRe(terms.mandatory);
 			validators.push(function(item) { return re.test(item.title) || re.test(item.body); })
 		}
 		if (terms && terms.positive.length) {
@@ -783,12 +783,14 @@ module.exports = function(hg) {
 					}
 
 				}
-
+																																																		
 				if (item.domain == 'members') {
+					// bonus for being a contributor
 					if (maxContributions > 0) {
-						return item.weight * (10*item.count/maxContributions);
+						return item.weight + (item.count/maxContributions/2);
 					}
-					return 0;
+					// nerf for being a non-contributor
+					return item.weight/2;
 				}
 				return item.weight;
 			});
